\name{PeriodicityTest}
\alias{PeriodicityTest}
\title{ Monte-Carlo test a series for periodicity }
\description{
Monte-Carlo testing for periodicity in short time series using likelihood-ratio statistic in
a fitted harmonic regression or Fisher's g statistic. 
Both tests are implemented as Monte-Carlo tests and can use more frequency components
than allowed by the regular FFT method.
Both tests allow missing values in the input series.
}

\usage{
PeriodicityTest(x, NSim = 10^4, Numf = 50, whichTest = c("g", "LR"), nullDis = c("n", "t", "b"), ...)
}

\arguments{
  \item{x}{ series }
  \item{NSim}{ number of Monte-Carlo iterations }
  \item{whichTest}{ "g" for Fisher's g statistic or "LR" for likelihood-ratio statistic }
  \item{nullDis}{ "n", "t", "b" corresponding to N(0,1) or t or bootstrap for generating samples
  from the null case }
  \item{Numf}{ Number of frequency components to use }
  \item{\dots}{ additional parameters, df and ncp, passed the rt }
}

\details{
The input series is simulated NSim times to obtain the Monte-Carlo test.
}

\value{
p-value.
}

\references{ 
Islam, M.S. (2008).  
Peridocity, Change Detection and Prediction in Microarrays. 
Ph.D. Thesis, The University of Western Ontario. 
}

\author{ A.I. McLeod }

\seealso{ \code{\link{FisherGTest}} }

\examples{
z<-SimulateHReg(10, f=2.5/10, 1, 2)
PeriodicityTest(z, Numf=50)

}

\keyword{ ts }
