c     calculate the periodogram at non-Fourier frequencies
c
c     **********************************************************************
      SUBROUTINE PG(Z,N,P,FREQ,NN,H)
c     **********************************************************************
c
c     input parameters
c     z - vector of length n containing the time series
c     n - length of the time series
c     nn - number of frequencies
cREMARK: when n is even and nn=n/2 we get the usual periodogram
c
c     output parameters
c     p - vector of length nn containing the periodogram
c     freq - vector of length nn containing the frequencies
c
      IMPLICIT DOUBLE PRECISION (A-H, O-Z)
      DOUBLE PRECISION Z(N), P(NN), FREQ(NN), H(2)
      DATA TWOPI/6.283185307179586D0/, TWO/2.0D0/, ZERO/0.0D0/
c
      ANGLE = TWOPI / DBLE(FLOAT(N))
      W = ZERO
c
      DO L = 1, NN
       W = W + ANGLE
c calculate the sine and cosine transformation at frequency w
       SINW = SIN(W)
       COSW = COS(W)
       COSNW = COSW
       SINNW = SINW
       S = ZERO
       C = ZERO
       DO I = 1, N
         C = C + COSNW * Z(I)
         S = S + SINNW * Z(I)
         TEMP = COSNW
         COSNW = COSW * TEMP - SINW * SINNW
         SINNW = SINW * TEMP + COSW * SINNW
       ENDDO
       P(L) = S * S + C * C
      ENDDO
c
c calculate the periodogram
      DO I = 1, NN
       FREQ(I) = DBLE(FLOAT(I))/DBLE(FLOAT(N))
       P(I) = P(I) / DBLE(FLOAT(N))
      ENDDO
c
c Fisher's g test
c adjust for when n is even
      NNADJ = NN
      IF (N/2*2.EQ.N) NNADJ = NN - 1
      PMAX = P(1)
      IND = 1
      DO I = 1, NNADJ
       SUMP = SUMP+P(I)
       IF (P(I) .GT. PMAX) THEN
       	PMAX = P(I)
	IND = I
       ENDIF
      ENDDO
      H(1) = FREQ(IND)
      H(2) = PMAX/SUMP
      RETURN
      END
