c     calculate the periodogram at non-Fourier frequencies
c
c     **********************************************************************
      SUBROUTINE PGNF(Z,INDNA,N,P,FREQ,NF,H,IFAULT)
c     **********************************************************************
c
c Evaluates at frequencies, i/(2*NF+1), i=1,...,NF
c     input parameters
c     z - vector of length n containing the time series
c     indna - vector of length n, =1 for missing value
c     n - length of the time series
c     nf - number of frequencies
cREMARK: when n is odd and nf=[n/2] we get the usual periodogram
c
c     output parameters
c     p - vector of length nf containing the periodogram
c     freq - vector of length nf containing the frequencies
c     h(1) = frequency corresponding to maximum; h(2) = Fisher's g (extension)
c     ifault = 0, ok. ifault=1, fewer than 4 observations
c
      IMPLICIT DOUBLE PRECISION (A-H, O-Z)
      DOUBLE PRECISION Z(N), P(NF), FREQ(NF), H(2)
      INTEGER INDNA(N)
      DATA TWOPI/6.283185307179586D0/, TWO/2.0D0/, ZERO/0.0D0/
c
c Corrected sum-of-squares
c
	ZM = ZERO
	NTOT = 0
	DO I = 1, N
	 IF(INDNA(I).NE.1) THEN
	   ZM = ZM+Z(I)
	   NTOT = NTOT+1
	 ENDIF
	ENDDO
	ZM = ZM/DBLE(FLOAT(NTOT))
	STOT = ZERO
	DO I = 1, N
	 IF(INDNA(I).NE.1) STOT = STOT+(Z(I)-ZM)*(Z(I)-ZM)
	ENDDO
	IFAULT = 0
	IF (NTOT .LT. 5) THEN
	  IFAULT = 1
	  RETURN
	ENDIF
c
      DNF21 = DBLE(FLOAT(2*NF+1))
      ANGLE = TWOPI / DNF21
      W = ZERO
      DO L = 1, NF
       W = W + ANGLE
c calculate the sine and cosine transformation at frequency w
       SINW = SIN(W)
       COSW = COS(W)
       COSNW = COSW
       SINNW = SINW
       S = ZERO
       C = ZERO
       DO I = 1, N
         IF(INDNA(I).NE.1) C = C + COSNW * Z(I)
         IF(INDNA(I).NE.1) S = S + SINNW * Z(I)
         TEMP = COSNW
         COSNW = COSW * TEMP - SINW * SINNW
         SINNW = SINW * TEMP + COSW * SINNW
       ENDDO
       P(L) = S * S + C * C
      ENDDO
c
c periodogram, Fisher's g at non-Fourier frequencies
c
      PMAX = ZERO
      INDMAX = 1
      DO I = 1, NF
       FREQ(I) = DBLE(FLOAT(I))/DNF21
       P(I) = P(I) / DBLE(FLOAT(NTOT))
       IF (P(I) .GT. PMAX) THEN
       	PMAX = P(I)
	INDMAX = I
       ENDIF
      ENDDO
      H(1) = FREQ(INDMAX)
      H(2) = TWO*PMAX/STOT
      RETURN
      END
